@@ -54,9 +54,6 @@ static const char *remoteUrlPrefixes[] = {
 #endif
 #ifdef ENABLE_CDIO_PARANOIA
 	"cdda://",
-#endif
-#ifdef ENABLE_DESPOTIFY
-	"spt://",
 #endif
 	NULL
 };
